@@ -1,5 +1,6 @@
 #include "item.h"
 #include <QStringList>
+#include <QMessageBox>
 
 PropertiesItem::PropertiesItem(QObject *parent) :
     QObject(parent)
@@ -49,9 +50,27 @@ void Item::Use(QScriptEngine* engine, QScriptValue* functions)
     QScriptValue objectValue = engine->newQObject(this);
     engine->globalObject().setProperty("Item", objectValue);
 
+    //Specific function:
     QScriptValue f = functions->property(QString("use_%1").arg(Name.replace("'", "").replace(" ", "")));
     if (f.isValid()){
         f.call();
+        return;
+    }
+
+    //Generic functions (healing items, ...):
+    if (GetEnduranceRestore() || GetCombatskillDelta()){
+        QString name = GetEnduranceRestore() ? "EnduranceRestore" : "CombatskillDelta";
+        f = functions->property(QString("use_%1").arg(name));
+        if (f.isValid()){
+            f.call();
+        }else{
+            QMessageBox msgBox(NULL);
+            msgBox.setWindowTitle(QString("Warning").arg(name));
+
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.setText(QString("No function found to use item: %1").arg(Name));
+            msgBox.exec();
+        }
     }
 }
 
