@@ -330,7 +330,9 @@ void FightWindow::MessageBox(QString title, QString message)
 
 void FightWindow::EndFight()
 {
+    m_Enemy->SetEndurance(0);
     ui->pbnClose->setVisible(true);
+    ui->pbnClose->setEnabled(true);
     ui->pbnEvade->setVisible(false);
     ui->pbnFight->setVisible(false);
 }
