@@ -38,7 +38,8 @@ RulesWindow::RulesWindow(QWidget *parent, QString bookDirectory) :
 #endif
 
     ui->webView->setContextMenuPolicy(Qt::NoContextMenu);
-    QUrl baseUrl = QUrl::fromLocalFile(QString("%1/Data/dummy.htm").arg(bookDirectory));
+    m_BookDirectory = bookDirectory;
+    /*QUrl baseUrl = QUrl::fromLocalFile(QString("%1/Data/dummy.htm").arg(bookDirectory));
     QFile input(QString("%1/rules.htm").arg(bookDirectory));
     if (input.open(QIODevice::ReadOnly)){
 #ifdef Q_WS_MAEMO_5
@@ -54,16 +55,40 @@ RulesWindow::RulesWindow(QWidget *parent, QString bookDirectory) :
         html.append(QString::fromUtf8(input.readAll()));
         html.append("</html>");
 
+        ui->webView->setHtml(html, baseUrl);
+    }*/
+}
+
+RulesWindow::~RulesWindow()
+{
+    delete ui;
+}
+
+void RulesWindow::ScrollToAnchor(QString anchor)
+{
+    ui->webView->page()->mainFrame()->evaluateJavaScript(QString("window.location.hash=\"%1\";").arg(anchor));
+}
+
+void RulesWindow::show()
+{
+    QMainWindow::show();
+
+    QUrl baseUrl = QUrl::fromLocalFile(QString("%1/Data/dummy.htm").arg(m_BookDirectory));
+    QFile input(QString("%1/rules.htm").arg(m_BookDirectory));
+    if (input.open(QIODevice::ReadOnly)){
+#ifdef Q_WS_MAEMO_5
+        QString css = "main_n900.css";
+#else
+        QString css = "main.css";
+#endif
+        QString html = QString("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"> \
+                        <html xmlns=\"http://www.w3.org/1999/xhtml\"> \
+                        <head> \
+                        <link type=\"text/css\" href=\"%1\" rel=\"stylesheet\" /> \
+                        </head>").arg(css);
+        html.append(QString::fromUtf8(input.readAll()));
+        html.append("</html>");
+
         ui->webView->setHtml(html, baseUrl);
     }
 }
-
-RulesWindow::~RulesWindow()
-{
-    delete ui;
-}
-
-void RulesWindow::ScrollToAnchor(QString anchor)
-{
-    ui->webView->page()->mainFrame()->evaluateJavaScript(QString("window.location.hash=\"%1\";").arg(anchor));
-}
